/**
 * Load context
 */
interface LoadContext {
    /**
     *  The format optionally supplied by the resolve hook chain
     */
    format?: string;
}
/**
 * The load hook provides a way to define a custom method of determining how a URL should be interpreted, retrieved, and parsed.
 * It is also in charge of validating the import assertion.
 * @see https://nodejs.org/docs/latest/api/esm.html#loadurl-context-nextload
 * @deprecated The loaders API is being redesigned. This hook may disappear or its signature may change. Do not rely on the API described below.
 * @param url The URL returned by the `resolve` chain
 * @param context Context
 * @param nextLoad The subsequent `load` hook in the chain, or the Node.js default `load` hook after the last user-supplied `load` hook
 */
export declare function load(url: string, context: LoadContext, nextLoad: unknown): unknown;
/**
 * Load context
 */
interface ResolveContext {
    /**
     * The module importing this one, or undefined if this is the Node.js entry point
     */
    parentURL?: string;
}
/**
 * The `resolve` hook chain is responsible for telling Node.js where to find and how to cache a given `import` statement or expression.
 * @see https://nodejs.org/docs/latest/api/esm.html#resolvespecifier-context-nextresolve
 * @deprecated The loaders API is being redesigned. This hook may disappear or its signature may change. Do not rely on the API described below.
 * @param specifier
 * @param context
 * @param nextResolve The subsequent `resolve` hook in the chain, or the Node.js default `resolve` hook after the last user-supplied resolve hook
 */
export declare function resolve(specifier: string, context: ResolveContext, nextResolve: unknown): Promise<unknown>;
export {};
